Blu's EPIC THREAD OF 'LOLs' and FAIL
Description: The online independent PlayStation 3 community.
Keywords: claud3, tickle me emo, gadget, thread

PSU - Playstation Universe
Watch PSU Community streams on Twitch.TV....LIVE!

### Latest PSU headlines:

Page 199 of 299 First ... 189 199 209 ... Last

- Jump to page:

Results 4,951 to 4,975 of 7470

# Thread: Blu's EPIC THREAD OF 'LOLs' and FAIL

- ###### Thread Tools

  - Show Printable Version
  - Email this Page…
  - Subscribe to this Thread…

- ###### Search Thread

  - Advanced Search

- ###### Display

  - Linear Mode
  - Switch to Hybrid Mode
  - Switch to Threaded Mode

1. 12-07-2011 #4951
   MedicDog
   - View Profile
   - View Forum Posts
   - Private Message
   - View Activity
   Forum Sage

   Join Date
     Jul 2008
   Age
     22
   Posts
     8,974
   Rep Power
     72
   Points
     7,870 (0 Banked)

   Reply With Quote

2. podsaurus, Itachi wishes they had posted this first.
3. 12-08-2011 #4952
   Ixion
   - View Profile
   - View Forum Posts
   - Private Message
   - View Activity
   Supreme Veteran

   Join Date
     Nov 2005
   Location
     New York
   PSN ID
     MagicManGSC
   Age
     23
   Posts
     19,683
   Rep Power
     152
   Points
     50,549 (0 Banked)
     Achievements

   Reply With Quote

4. 12-08-2011 #4953
   podsaurus
   - View Profile
   - View Forum Posts
   - Private Message
   - View Activity
   El Presidente

   Join Date
     Jul 2008
   Location
     in a box
   Age
     22
   Posts
     3,683
   Rep Power
     65
   Points
     9,163 (0 Banked)

   > @Mael How I am waking up. It's a new day! Oh...ZZZzzzzzz....
   > @Medic :P Imagine the guy driving down the wrong side of the road.
   > @Ixion What I'd like to do with some people.
   > Just found this one.

   Reply With Quote

5. bash , Itachi wishes they had posted this first.
6. 12-08-2011 #4954
   BBK..
   - View Profile
   - View Forum Posts
   - Private Message
   - View Activity
   Forum Sage

   Join Date
     Oct 2008
   Location
     Bristol!!
   Age
     24
   Posts
     8,401
   Rep Power
     77
   Points
     21,321 (15,799 Banked)

   > Unimpressed Astronauts

   > BoyBettaKnow
   > Can people please stop calling PS4 and XBOne 'next gen'. Both systems are now out. It's now the current generation.

   Reply With Quote

7. bash , podsaurus, Itachi wishes they had posted this first.
8. 12-08-2011 #4955
   MedicDog
   - View Profile
   - View Forum Posts
   - Private Message
   - View Activity
   Forum Sage

   Join Date
     Jul 2008
   Age
     22
   Posts
     8,974
   Rep Power
     72
   Points
     7,870 (0 Banked)

   Reply With Quote

9. 12-08-2011 #4956
   Rapture
   - View Profile
   - View Forum Posts
   - Private Message
   - View Activity
   Apollyon

   Join Date
     Aug 2005
   Location
     Equestria
   Age
     21
   Posts
     14,258
   Rep Power
     117
   Points
     34,464 (0 Banked)
     Achievements

   > Choo choo

   > PSU's Elected Best Games of All Time - Voting [Round Four]
   > [Forum Rules] - [Steam]

   Reply With Quote

10. Sufi, unicron7, Itachi , podsaurus, Aldebaran wishes they had posted this first.
11. 12-09-2011 #4957
    Aldebaran
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Could it be...I am sleeping?

    Join Date
      Mar 2009
    Location
      Arabian Deserts
    Posts
      5,056
    Rep Power
      60
    Points
      2,865 (0 Banked)
      Items

    > Originally Posted by darky89
    > I've never laughed as much at my laptop screen. I f***** cried.
    > ________
    > 'Soon' memes are freakin' hilarious.

    > Who I Am
    > _________
    > Currently Playing: Harvest Moon (3DS)
    > Recently Completed: Parasite Eve I & II, Wild ARMs, Mario 3D Land, ICO & SoTC HD, Zelda: OoT 3D, VVVVVV, Gravity Rush

    Reply With Quote

12. Itachi wishes they had posted this first.
13. 12-09-2011 #4958
    Thorzilla
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Elite Sage

    Join Date
      Feb 2006
    Age
      23
    Posts
      11,787
    Rep Power
      108
    Points
      43,357 (713 Banked)
      Items
      Achievements

    > |My Playfire|My Deviantart|
    > - SIG BY MY SISTER-

    Reply With Quote

14. 12-09-2011 #4959
    podsaurus
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    El Presidente

    Join Date
      Jul 2008
    Location
      in a box
    Age
      22
    Posts
      3,683
    Rep Power
      65
    Points
      9,163 (0 Banked)

    Reply With Quote

15. 12-09-2011 #4960
    x6Teen
    - View Profile
    - View Forum Posts
    - Private Message
    - Visit Homepage
    - View Activity
    JACK3D

    Join Date
      Feb 2011
    Location
      Leg Press Machine
    Posts
      4,129
    Rep Power
      37
    Points
      5,434 (0 Banked)
      Items

    > Sig made by Spyrde

    Reply With Quote

16. Aldebaran wishes they had posted this first.
17. 12-09-2011 #4961
    Aldebaran
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Could it be...I am sleeping?

    Join Date
      Mar 2009
    Location
      Arabian Deserts
    Posts
      5,056
    Rep Power
      60
    Points
      2,865 (0 Banked)
      Items

    > Originally Posted by x6Teen
    > hot.

    > Who I Am
    > _________
    > Currently Playing: Harvest Moon (3DS)
    > Recently Completed: Parasite Eve I & II, Wild ARMs, Mario 3D Land, ICO & SoTC HD, Zelda: OoT 3D, VVVVVV, Gravity Rush

    Reply With Quote

18. 12-09-2011 #4962
    Nick_Scryer
    - View Profile
    - View Forum Posts
    - Private Message
    - Visit Homepage
    - View Activity
    Elite Member

    Join Date
      May 2007
    Location
      At Home
    Age
      24
    Posts
      1,868
    Rep Power
      59
    Points
      3,240 (0 Banked)
      Items

    > Click HERE for my Videos

    Reply With Quote

19. 12-09-2011 #4963
    Ixion
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Supreme Veteran

    Join Date
      Nov 2005
    Location
      New York
    PSN ID
      MagicManGSC
    Age
      23
    Posts
      19,683
    Rep Power
      152
    Points
      50,549 (0 Banked)
      Achievements

    > Originally Posted by Nick_Scryer
    > I posted this about a month ago!
    > Still funny though.

    Reply With Quote

20. 12-10-2011 #4964
    bash
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Veteran

    Join Date
      Aug 2009
    Location
      Ontario Canada
    Age
      21
    Posts
      4,531
    Rep Power
      53
    Points
      1,708 (4,812 Banked)
      Items

    > 2010 Lethal's FF League Champion

    Reply With Quote

21. unicron7 wishes they had posted this first.
22. 12-10-2011 #4965
    .RAID3N.
    - View Profile
    - View Forum Posts
    - Private Message
    - Visit Homepage
    - View Activity
    Veteran

    Join Date
      May 2006
    Location
      Fort Collins
    Age
      28
    Posts
      4,478
    Rep Power
      73
    Points
      723 (6,474 Banked)
      Items

    > Originally Posted by bash

    > Originally Posted by Mike Birbiglia
    > Why would you go talk about computers when you could stay here and go skiing and your skis will be french toast sticks!

    Reply With Quote

23. 12-10-2011 #4966
    mickice
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Ultimate Veteran

    Join Date
      Oct 2006
    Location
      Australia, In a Kangaroo's pouch.
    Age
      26
    Posts
      21,391
    Rep Power
      121
    Points
      8,809 (40,000 Banked)
      Items
      Achievements

    > Last edited by mickice; 12-10-2011 at 10:04.

    Reply With Quote

24. 12-10-2011 #4967
    unicron7
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Veteran

    Join Date
      Dec 2007
    Location
      A little place called none of your **** business. United States.
    Age
      28
    Posts
      4,674
    Rep Power
      73
    Points
      5,549 (0 Banked)
      Items

    > [COLOR=#fafafa !important]
    > [/COLOR]

    > I don't really need a water cooler/remote control as of right now.

    Reply With Quote

25. spyrde wishes they had posted this first.
26. 12-10-2011 #4968
    x6Teen
    - View Profile
    - View Forum Posts
    - Private Message
    - Visit Homepage
    - View Activity
    JACK3D

    Join Date
      Feb 2011
    Location
      Leg Press Machine
    Posts
      4,129
    Rep Power
      37
    Points
      5,434 (0 Banked)
      Items

    > Sig made by Spyrde

    Reply With Quote

27. 12-10-2011 #4969
    DreDayDetox
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Master Sage

    Join Date
      Nov 2007
    Location
      Shadow Moses
    PSN ID
      That's for me to know and you to find out.
    Posts
      12,516
    Rep Power
      100
    Points
      13,485 (0 Banked)
      Items
      Achievements

    > I did that. Describes mine pretty well.
    > ROFLMFAO! I found this hotspot at college a few weeks ago..Whoever thought up of that for their wifi connection name should get the nobel peace prize for the epic lulz that ensued upon that day

    Reply With Quote

28. Itachi wishes they had posted this first.
29. 12-10-2011 #4970
    mickice
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Ultimate Veteran

    Join Date
      Oct 2006
    Location
      Australia, In a Kangaroo's pouch.
    Age
      26
    Posts
      21,391
    Rep Power
      121
    Points
      8,809 (40,000 Banked)
      Items
      Achievements

    > Originally Posted by DreDayDetox
    > I did that. Describes mine pretty well.
    > Curved and spotty?

    Reply With Quote

30. Itachi wishes they had posted this first.
31. 12-10-2011 #4971
    spyrde
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Master Guru

    Join Date
      Feb 2009
    Location
      Finland
    Posts
      6,814
    Rep Power
      87
    Points
      73,315 (0 Banked)
      Items

    > Originally Posted by unicron7
    > epic lols were had

    > Last edited by spyrde; 12-10-2011 at 12:47.

    > Learn to do signatures here

    Reply With Quote

32. darky89 , Itachi , Aldebaran wishes they had posted this first.
33. 12-10-2011 #4972
    darky89
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Master Guru

    Join Date
      Dec 2007
    Location
      In the bushes.
    Age
      24
    Posts
      6,499
    Rep Power
      82
    Points
      31,429 (0 Banked)
      Items

    > Originally Posted by spyrde
    > epic lols were had
    > You never post anything funny.

    > Don't Steal. Don't Molest Little Children. Don't Deal Drugs.
    > Mark 'Second Coming of Jesus' Cerny - "I'm a baby killer"

    Reply With Quote

34. 12-10-2011 #4973
    Vip3r
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Super Elite

    Join Date
      Apr 2007
    Posts
      2,498
    Rep Power
      65
    Points
      5,248 (0 Banked)

    > ix9Gt.jpg
    > So true. So true.

    > i5-2500k @3.3Ghz, Gigabyte GA-Z68XP-UD4, Crucial 4GB 1333Mhz RAM,
    > Palit GTS 250 1GB, 2x WD 250GB, 1x 1TB Samsung F3,
    > Corsair HX850W PSU, Cooler Master 690 II,
    > Checkout my TF2 Replay Video.

    Reply With Quote

35. 12-11-2011 #4974
    x6Teen
    - View Profile
    - View Forum Posts
    - Private Message
    - Visit Homepage
    - View Activity
    JACK3D

    Join Date
      Feb 2011
    Location
      Leg Press Machine
    Posts
      4,129
    Rep Power
      37
    Points
      5,434 (0 Banked)
      Items

    > never laughed so hard at a thread in a while http://forum.bodybuilding.com/showth...hp?t=140401093

    > Sig made by Spyrde

    Reply With Quote

36. 12-11-2011 #4975
    Itachi
    - View Profile
    - View Forum Posts
    - Private Message
    - View Activity
    Selected Members Council

    Join Date
      Nov 2010
    Location
      Winterfell
    PSN ID
      iwinulose042
    Age
      20
    Posts
      7,866
    Rep Power
      75
    Points
      17,245 (151,503 Banked)
      Items

    > lmao at u guys saying every black celebrity looks like a gorilla
    > I agree with this guy on that thread

    Reply With Quote

Page 199 of 299 First ... 189 199 209 ... Last

- Jump to page:

Quick Navigation Off-Topic Top

- Site Areas
- Settings
- Private Messages
- Subscriptions
- Who's Online
- Search Forums
- Forums Home
- Forums
- PSU Community HUB
  1. Forum Rules, Help & Feedback
     1. Infractions & Bans
  2. Announcements
  3. Media Content
     1. PSUtube
        1. SE500 Shorts
     2. PlayStation Unchained Podcast
     3. Community Question Of The Week
  4. PSU Twitch TV Schedules
     1. Community Twitch TV Schedules
  5. Community Reviews & Opinions
  6. Design Corner
     1. Sig/Avy Requests
- PlayStation Chat
  1. PlayStation 4
  2. PlayStation 4 Games
  3. PlayStation 3
  4. PlayStation 3 Games
     1. DUST 514
     2. GTA V
     3. Call of Duty
     4. FFXIV: ARR
  5. PlayStation Vita
  6. PlayStation Legacy
  7. PlayStation Network
- Other Gaming Chat
  1. Xbox
     1. Xbox Games
  2. Nintendo
  3. PC Gaming
  4. Other Gaming
  5. PlayStation vs Xbox
- General Forums
  1. Off-Topic
     1. Forum Games
  2. Entertainment
  3. Sports
  4. Technology

« Previous Thread | Next Thread »

#### Thread Information

##### Users Browsing this Thread

There are currently 2 users browsing this thread. (0 members and 2 guests)

#### Similar Threads

1. ###### Whats your favorite band????

   By Trinity in forum Off-Topic
   Replies: 114
   Last Post: 07-17-2010, 08:31

2. ###### PRICE

   By MasterMc in forum PlayStation 3
   Replies: 4
   Last Post: 06-03-2009, 01:40

3. ###### 40GB PS3 is still compatible with PSone games

   By sorrow880 in forum PlayStation 3
   Replies: 14
   Last Post: 10-09-2007, 10:57

4. ###### Microsoft Servers Run By Ps3!!

   By streetracer67856 in forum Trash Can
   Replies: 29
   Last Post: 09-21-2007, 04:52

5. ###### New Bullet Witch Preview

   By Tribunal in forum Xbox
   Replies: 3
   Last Post: 08-05-2006, 21:42

#### Tags for this Thread

claud3, tickle me emo

View Tag Cloud

#### Bookmarks

- Digg
- del.icio.us
- StumbleUpon
- Google

#### Posting Permissions

- You may not post new threads
- You may not post replies
- You may not post attachments
- You may not edit your posts

- BB code is On
- Smilies are On
- [IMG] code is On
- HTML code is On

Forum Rules

# PSU

## Playstation Universe

Copyright 2006-2012 Abstract Holdings International Ltd. All Right Reserved.

Reproduction in whole or in part in any form or medium without express written permission of Abstract Holdings International Ltd. prohibited.
Use of this site is governed by our Terms of Use and Privacy Policy.

## PSU.com

- Contact
- Advertise
- Staff
- Jobs

- Privacy Policy &
  Terms and Conditions
- Wallpapers
- Upload a wallpaper
- Upload a PS3 Theme

- RSS Feed
- PodCasts
- Events
- Game rankings

## Recommended Gaming Sites:

- Armchair Empire
- Creative Uncut
- Chapter Cheats
- Cheats
- CheatHappens
- Free MMORPG
- Gamers Brain
- Game Cheats
- Game Design
- GamerZines
- Gaming Chair
- Gaming Chairs
- La PS3
- Max PS3
- PS3 Attitude
- PS3 Center
- PS3 cheats
- PS3 Informer
- PS3 Vault
- Talk Xbox
- Xbox 360 Cheats
- Xbox 360 News
- Zelda Dungeon

vBCredits II Deluxe v2.1.0 (Pro) - vBulletin Mods & Addons Copyright © 2010-2013 DragonByte Technologies Ltd.